[python-hdf5storage] 04/84: Fixed bug where Attribute MATLAB_fields is not deleted for non-structured ndarrays.

Ghislain Vaillant ghisvail-guest at moszumanska.debian.org
Mon Feb 29 08:24:57 UTC 2016


This is an automated email from the git hooks/post-receive script.

ghisvail-guest pushed a commit to annotated tag 0.1.10
in repository python-hdf5storage.

commit 72d97a1a5accb2f694987187e70276b5e0fde809
Author: Freja Nordsiek <fnordsie at gmail.com>
Date:   Sun Aug 10 17:30:01 2014 -0400

    Fixed bug where Attribute MATLAB_fields is not deleted for non-structured ndarrays.
---
 hdf5storage/Marshallers.py | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/hdf5storage/Marshallers.py b/hdf5storage/Marshallers.py
index 1eb034e..83267eb 100644
--- a/hdf5storage/Marshallers.py
+++ b/hdf5storage/Marshallers.py
@@ -785,12 +785,14 @@ class NumpyScalarArrayMarshaller(TypeMarshaller):
                 grp[name][...] = data_to_store
 
             # Write the metadata using the inherited function (good
             # enough). The Attribute 'Python.numpy.fields, if present,
             # needs to be deleted since this isn't a structured ndarray.
 
             self.write_metadata(f, grp, name, data, type_string,
                                 options)
             del_attribute(grp[name], 'Python.Fields')
+            del_attribute(grp[name], 'MATLAB_fields')
 
     def write_metadata(self, f, grp, name, data, type_string, options):
         # First, call the inherited version to do most of the work.
@@ -785,12 +785,14 @@ class NumpyScalarArrayMarshaller(TypeMarshaller):
 
             # Write the metadata using the inherited function (good
-            # enough). The Attribute 'Python.numpy.fields, if present,
-            # needs to be deleted since this isn't a structured ndarray.
+            # enough). The Attributes 'Python.numpy.fields' and
+            # 'MATLAB_fields', if present, need to be deleted since this
+            # isn't a structured ndarray.
 
             self.write_metadata(f, grp, name, data, type_string,

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/debian-science/packages/python-hdf5storage.git



More information about the debian-science-commits mailing list